#ifndef NT2_INCLUDE_FUNCTIONS_NEGATE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NEGATE_HPP_INCLUDED

#include <nt2/ieee/include/functions/negate.hpp>

#endif
